remove extra line from Bosses,

His Dad [05-05-15 - 09:39]
remove extra line from Bosses,
Show some Quest data
Filename
HistOffline.lua
diff --git a/HistOffline.lua b/HistOffline.lua
index 0966844..6b1e0e9 100644
--- a/HistOffline.lua
+++ b/HistOffline.lua
@@ -256,7 +256,7 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 		accounts[acc].name[char].Grp_box = iup.matrix {numcol=4, numcol_visible=4,  numlin=5, widthdef=90}
 		--Set Column titles
 		for i=1, 4 do
-			accounts[acc].name[char].Grp_box:setcell(0,i, Area_names[i].medium)
+			accounts[acc].name[char].Grp_box:setcell(0,i, Area_names[i].long)
 		end
 		--set lines
 		accounts[acc].name[char].Grp_box:setcell(0,0, L.Level)
@@ -316,7 +316,7 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 		-- Create Pub Dungeon Achievements Box==========================
 		accounts[acc].name[char].Pub_box = iup.matrix {numcol=4, numcol_visible=4,  numlin=5, widthdef=90}
 		for i=1, 4 do  -- Load text
-			accounts[acc].name[char].Pub_box:setcell(0,i, Area_names[i].medium)
+			accounts[acc].name[char].Pub_box:setcell(0,i, Area_names[i].long)
 		end

 		accounts[acc].name[char].Pub_box:setcell(0,0, L.Level)
@@ -369,7 +369,7 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 		accounts[acc].name[char].Vet_box= iup.matrix {numcol=5, numcol_visible=5,  numlin=5, widthdef=110}

 		for i=1, 5 do  -- Load headings
-			accounts[acc].name[char].Vet_box:setcell(0,i, Area_names[i].medium)
+			accounts[acc].name[char].Vet_box:setcell(0,i, Area_names[i].long)
 		end

 		iup.SetAttribute(accounts[acc].name[char].Vet_box, "READONLY", "YES")
@@ -483,10 +483,10 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 		Line= Line +1
 		end
 -- Create WorldBoss Achievements Box==========================
-		accounts[acc].name[char].WB_box= iup.matrix {numcol=4, numcol_visible=4,  numlin=6, widthdef=110}
+		accounts[acc].name[char].WB_box= iup.matrix {numcol=4, numcol_visible=4,  numlin=5, widthdef=110}

 		for i=1, 4 do  -- Load headings, not craglorn
-			accounts[acc].name[char].WB_box:setcell(0,i, Area_names[i].medium)
+			accounts[acc].name[char].WB_box:setcell(0,i, Area_names[i].long)
 		end
 		accounts[acc].name[char].WB_box:setcell(0,0, L.Zone)
 		accounts[acc].name[char].WB_box:setcell(1,0, "1")
@@ -551,10 +551,10 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 		end

 -- Create SkillQuest Achievements Box==========================
-		accounts[acc].name[char].SQ_box= iup.matrix {numcol=4, numcol_visible=4,  numlin=6, widthdef=110}
-
+		accounts[acc].name[char].SQ_box= iup.matrix {numcol=4, numcol_visible=4,  numlin=5, widthdef=110}
+		accounts[acc].name[char].SQ_Info = {}
 		for i=1, 4 do  -- Load headings, not craglorn
-			accounts[acc].name[char].SQ_box:setcell(0,i, Area_names[i].medium)
+			accounts[acc].name[char].SQ_box:setcell(0,i, Area_names[i].long)
 		end
 		accounts[acc].name[char].SQ_box:setcell(0,0, L.Zone)
 		accounts[acc].name[char].SQ_box:setcell(1,0, "1")
@@ -572,9 +572,10 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 		iup.SetAttribute(accounts[acc].name[char].SQ_box,  "FGCOLOR*:5", Colour_Not_Complete)

 		-- Need to keep track of multiple achievements for SQ in Zones. Index them by zone LineColumn.
-		SQ_Info={}
+		SQ_Info = accounts[acc].name[char].SQ_Info
 		SQ_Area={}
-		for id,_ in pairs (SQ_dat) do  -- Load World Boss Name. Info LC is the ZONE Identifier
+		SQ_count = {}
+		for id,_ in pairs (SQ_dat) do  -- Load all Quest Data. Info LC is the ZONE Identifier
 				local L = SQ_dat[id].L
 				local C = SQ_dat[id].C
 				key = tostring(L) .. tostring(C)	-- make name key
@@ -582,8 +583,12 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 					if dname == nil then
 				dname = "key " .. key .." not found"
 				end
-				SQ_Info[key] = {count = 0}
+
+				SQ_Info[key] = {}
+				SQ_Info[key].quest = {}
+				SQ_count[key] = {count= 0}
 				SQ_Area[C] =0
+
 				accounts[acc].name[char].SQ_box:setcell(L,C,dname .. " (0)")
 		end

@@ -601,25 +606,22 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 					dname = "SQ key " .. key .." not found"
 				end
 				-- Increment count and display
-				SQ_Info[key].count = SQ_Info[key].count+1
-				accounts[acc].name[char].SQ_box:setcell(L,C,dname .. " (" .. SQ_Info[key].count ..")")
+				SQ_count[key].count = SQ_count[key].count+1
+				accounts[acc].name[char].SQ_box:setcell(L,C,dname .. " (" .. SQ_count[key].count ..")")
 				--Check if done
-				if  SQ_Info[key].count >= 6 then
+				if  SQ_count[key].count >= 2 then
 					iup.SetAttribute(accounts[acc].name[char].SQ_box, colour_cell , Colour_Complete)
 				end
 				--Add to Area Completion
 				SQ_Area[C] = SQ_Area[C] +1
-			end
-		end
-		--Set Column Colours if 30 done.
-		for i,j in pairs (SQ_Area) do
-		if j > 29 then
-			iup.SetAttribute(accounts[acc].name[char].SQ_box,  "BGCOLOR0:".. tostring(i), Colour_Heading_Complete)
-		end
-		end


-	--	accounts[acc].name[char].SQ_box.Redraw= "ALL" -- Doesnt seem to be needed.
+			-- This is where we store detail for each cell for popup
+			-- For each LC, lookup the quest ID's that we have.
+
+			table.insert(SQ_Info[key].quest, id)
+			end
+		end



@@ -676,7 +678,7 @@ btn_archive = iup.button{title="Archive", FGCOLOR = "#FF0000"}
 												iup.label{title=L.SkillLab,expand="HORIZONTAL"},
 												accounts[acc].name[char].SQ_box,
 												iup.fill{}
-											},
+											},
 								},	-- end of tabs for dungeons
 							},
 					}  -- end of tabs for characters vbox